#!/usr/bin/env python
"""   
 @file: MainWindow.py  
  File is a part of Scribo Project  
  Module implements main window from UI
  @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
  @date: 23.06.2010
"""

__author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
__version__ = "$Revision: 0.2 $"
__date__ = "$Date: 2010/06/23 $"
__copyright__ = ""
__license__ = "GPLv2"


import sys
from PyQt4 import QtCore
from PyQt4 import QtGui
from ldm.Profile import main_prof

class MainWindow(QtGui.QMainWindow):
    """
    main class for all windows
    @version  1.0   
    @author  Zaiceva Diana <zaiceva@cs.karelia.ru>   
    """
    def __init__(self, parent=None):
        """
        Initialization for MainWindow   
        @param parent (widget), start (string) 
        @return 
        """
        QtGui.QMainWindow.__init__(self, parent)
        self.setWindowTitle(self.tr("Scribo"))
        self.setMinimumSize(160, 160)
        self.resize(480, 340)

        try:
            self.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow)
        except AttributeError:
            print "no stacked attribute"
        
        self.parent = parent
        self.new_act = QtGui.QAction(self.tr("&New Account"), self)
        self.manage_act = QtGui.QAction(self.tr("&Edit Accounts"), self)
        self.create_actions_menu()
        self.create_menus()
        

    def new_profile(self):
        """
        change window on "add profile"
        @param 
        @return
        """
        from AddProfile import AddProfileWindow
        add_widg = AddProfileWindow(self)
        

    def manage_profile(self):
        """
        change window on "manage profile"
        @param 
        @return
        """
        from AddProfile import AddProfileWindow
        add_widg = AddProfileWindow(self, default=main_prof.def_account)

    def draft(self):
        """
        change window on "manage profile"
        @param 
        @return
        """
        self.dial = QtGui.QMessageBox()
        self.list_drafts = self.view_list_drafts()
        vbox = QtGui.QVBoxLayout()
        but_box = QtGui.QDialogButtonBox()
        but_box.setOrientation(QtCore.Qt.Horizontal)
        
        self.dial.setWindowTitle(self.tr("Drafts"))
        self.dial.setOrientation(QtCore.Qt.Horizontal)

        self.send_button = but_box.addButton(self.tr("Send"),
                                     QtGui.QDialogButtonBox.ActionRole)
        self.edit_button = but_box.addButton(self.tr("Edit"),
                                       QtGui.QDialogButtonBox.ActionRole)
        self.remove_button = but_box.addButton(self.tr("Delete"),
                                       QtGui.QDialogButtonBox.ActionRole)
       
        cancel_button = self.dial.addButton(QtGui.QMessageBox.Abort)
        cancel_button.hide()
        but_box.adjustSize()
        self.list_drafts.adjustSize()        
        vbox.addWidget(self.list_drafts)
        vbox.addWidget(but_box,3, QtCore.Qt.AlignCenter)
        self.dial.layout().addLayout(vbox, 0, 0, -1, -1, QtCore.Qt.AlignCenter)      
        #self.dial.layout().addWidget(but_box, 10, 0, 1, 3, QtCore.Qt.AlignCenter)
        self.dial.layout().setRowMinimumHeight(0,300)        

        self.connect(but_box, QtCore.SIGNAL("clicked(QAbstractButton *)"), self.draft_click)
        self.dial.exec_()
        if self.dial.clickedButton() == QtGui.QMessageBox.Abort:
            pass
        else:
            return

    def view_list_drafts(self):
        """
        QListWidget with list of drafts
        """
        from ldm.Draft import get_drafts
        self.drafts = get_drafts()
        list_widget = QtGui.QListWidget()
        list_widget.setResizeMode(QtGui.QListView.Adjust)
        list_widget.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
        index = 0    
        for mes in self.drafts:
            date = mes.date
            if date:
                import time
                datetime = time.strptime(date, "%Y-%m-%d %H:%M:%S")
                date = time.strftime("%a, %d %b %Y %H:%M", datetime)
            else:
               date = ""
            if not mes.title:
                title = unicode(self.tr("no subject"))
            else:
                title = unicode(mes.title)
            text = date.decode('utf8') + "  " + title

            author = mes.poster
            icon = ""
            if author:
               text = text + "  (" + author + ")"
               icon = author.get_icon()
               if not icon:
                   icon = ""
            print text
            new_item = QtGui.QListWidgetItem(QtGui.QIcon(QtCore.QString(icon)),
                                             text,
                                             list_widget)
            new_item.setData(1, QtCore.QVariant(index))
            index = index + 1
            del text
            del title
            del date
        
        return list_widget


    def draft_click(self, button):
        """                                                                                                                                      
        dialog adding html in the text                                                                                                             
        """
        list = self.list_drafts.selectedItems()
        if list or not list == []:
            index = list[0].data(1).toString().toInt()[0]
            mes = self.drafts[index]
        else:
            self.dial.reject()
            if self.drafts == []:
                QtGui.QMessageBox.information(self, self.tr("Scribo"),
                               self.tr("List of drafts is empty!"),
                               QtGui.QMessageBox.Yes)
            else:
                QtGui.QMessageBox.information(self, self.tr("Scribo"),
                               self.tr("Please, choose messages!"),
                               QtGui.QMessageBox.Yes)
            return
        if button == self.send_button:
            from RepeatPost import RepeatPost
            send_window = RepeatPost(self,mes)
        elif button == self.edit_button:
            from AddPost import AddPostWindow
            add_window = AddPostWindow(self, mes)
        elif button == self.remove_button:
             mes.del_msg_tree()            
             self.list_drafts.removeItemWidget(list[0])
             list[0].setHidden(True)
             list[0].setSelected(False)

        else:
                return
        if not button == self.remove_button:
            self.dial.reject()

    

    def about(self):
        """  
        page with info about application
        @param 
        @return
        """
        from About import __version__ as ver
        QtGui.QMessageBox.about(self, self.tr("About Scribo"),
                                self.tr("A mobile multiblog client."\
                                        " \n Version: " + ver+
                                        "\n More information you can get from README file."))
    def show_warning(self, exc):
        """  
        error message
        @param exc - exception
        @return
        """

        QtGui.QMessageBox.warning(self,
                                  self.tr("Scribo"),
                                  exc.to_html(),
                                  QtGui.QMessageBox.Ok)


    def create_actions_menu(self):
        """
        create submenu
        @param
        @return
        """
        self.new_act.setShortcut(self.tr("Ctrl+N"))
        self.connect(self.new_act, QtCore.SIGNAL("triggered()"),
                     self.new_profile)

        self.connect(self.manage_act, QtCore.SIGNAL("triggered()"),
                     self.manage_profile)

        self.exit_act = QtGui.QAction(self.tr("E&xit"), self)
        self.exit_act.setShortcut(self.tr("Ctrl+Q"))
        self.connect(self.exit_act, QtCore.SIGNAL("triggered()"),
                     self, QtCore.SLOT("close()"))

        bold_font = self.exit_act.font()
        bold_font.setBold(True)
        self.exit_act.setFont(bold_font)

        self.about_act = QtGui.QAction(self.tr("&About"), self)
        self.connect(self.about_act, QtCore.SIGNAL("triggered()"), self.about)

        self.draft_act = QtGui.QAction(self.tr("Drafts"), self)
        self.connect(self.draft_act, QtCore.SIGNAL("triggered()"), self.draft)


    def create_menus(self):
        """
        create menu
        @param
        @return
        """
        self.main_menu = self.menuBar().addMenu(self.tr("&Menu"))
        self.main_menu.addAction(self.new_act)
        self.main_menu.addAction(self.manage_act)
        self.main_menu.addAction(self.about_act)
        self.main_menu.addAction(self.draft_act)
        self.main_menu.addSeparator()
        self.main_menu.addAction(self.exit_act)



    def closeEvent(self, event):
        """
        handler for clicked "back" 
        @param
        @return
        """
        event.accept()
        if self.parent:
            self.parent.show()
        else:
            ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
                                             self.tr("Do you really want to quit?"),
                                             QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
            if (ret == QtGui.QMessageBox.No):
                event.ignore()
                return
    
    def home_window(self):
        """
        handler for clicked "home"
        @param
        @return
        """
        parent = self.parent
        child = self
        del_window = []
        while parent<>None:
            del_window.append(child)
            child = parent
            parent = parent.parent
            
        for window in del_window:
            window.close()
	child.show()
	return child
	
    def reload_home_window(self):
        """
        reload home window (if profile is changed)
        @param
        @return
        """
        self = self.home_window()
        if not main_prof.accounts:
           from StartPage import StartPage
           self.parent = StartPage()
        else:
            from HomePage import HomePage
	    home_page = HomePage(main_prof.def_account)
            self.parent = home_page 
        self = self.home_window()
        
main_window = MainWindow()


